/**
 * Details : コメントアイテム設定ファイル
 */

/**
 * 初期化
 */
function init(){

    return {
        id          : 'sample_item_imwComment',
        icon        : 'forma_sample_items-icon-application--pencil',
        title       : 'MSG.I.FORMA.ITEM.COMMENT.TITLE',
        preload     : false,
        defaultStyle: {
                height : '100px',
                width  : '450px'
        },
        // スマートフォン版対応
        mobileFriendly : true
    };
}

/**
 * ユーザ入力バリデーション
 *
 * ユーザがフォームへ入力した値に対して、
 * フォーム作成時に設定した内容で入力チェックを行なう。
 * 返却形式 : { error : {Boolean} チェック結果
 *              message : {String} エラーメッセージ
 *              acceptErrorObj : {Object} エラー状態表示関数への引数
 *            }
 *
 * @param {Object} setting アイテム設定データ
 * @param {Object} data ユーザ入力データ
 * @return {Object} チェック結果
 */
function validate(setting, data) {

    if ( typeof LIBRARY === 'undefined') {
        load('forma/designer/types/items_library');
    }
    var itemSetting    = setting.input_list[0];
    var inputId        = itemSetting.input_id;
    var inputName    = itemSetting.input_view_names[ Contexts.getAccountContext().locale ];
    var result        = null;

    var inputValue = data[ inputId ];

    /** 必須チェック */
    if(itemSetting.input_properties.required){
        result    = LIBRARY.validation.client.required( inputId, inputValue, inputName );
        if(result.error) return result;
    }

    /** 最小入力文字 */
    result    = LIBRARY.validation.client.minLength( inputId, inputValue, itemSetting.input_properties.min_length, inputName );
    if(result.error) return result;

    /** 最大入力文字 */
    result    = LIBRARY.validation.client.maxLength( inputId, inputValue, itemSetting.input_properties.max_length, inputName );
    if(result.error) return result;

    /** 正規表現で設定された入力チェック */
    var properties = itemSetting.input_properties;
    if ( !(properties.custom_input_chk === null || properties.custom_input_chk === undefined
        || properties.custom_chk_format === null || properties.custom_chk_format === undefined
        || properties.custom_err_msg === null || properties.custom_err_msg === undefined) ) {

        var chkFormat = properties.custom_chk_format;
        var errMsg = properties.custom_err_msg[ Contexts.getAccountContext().locale ];
        result = LIBRARY.validation.client.customChkFormat( inputId, inputValue, chkFormat, errMsg, inputName );
        if(result.error) return result;
    }

    /** エラー無し */
    return {
        error : false,
        acceptErrorObj : { inputId : inputId }
    };
}

/**
 * プロパティ入力バリデーション
 *
 * フォーム作成時のアイテムプロパティへ入力した値に対して入力チェックを行なう。
 * プロパティパネルを閉じる時とデータ登録直前で共通使用。
 * サーバサイドフラグが、falseの時は各項目のエラーを一括で返却、
 * trueの時はエラーが見つかった時点で返却。
 *
 * @param {Object} setting アイテム設定データ
 * @param {Boolean} [serverFlg] サーバサイドチェックフラグ
 * @return {Object} チェック結果
 */
function propertiesValidate( setting, serverFlg ) {

    if ( typeof LIBRARY === 'undefined') {
        load('forma/designer/types/items_library');
    }
    var errorArray = [];
    var result = null;

    /** ラベル名 */
    result = LIBRARY.validation.properties.labelName( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray = errorArray.concat( result.errorArray );
        }
    }

    /** 最小入力文字数 */
    result = LIBRARY.validation.properties.valueLength( setting, serverFlg, 'min_length' );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 最大入力文字数 */
    result = LIBRARY.validation.properties.valueLength( setting, serverFlg, 'max_length' );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 最小・最大文字数の整合性チェック */
    result = LIBRARY.validation.properties.lengthIntegrity( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** カスタム入力チェックのチェックフォーマット */
    result = LIBRARY.validation.properties.customChkFormat( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** カスタム入力チェックのエラーメッセージ */
    result = LIBRARY.validation.properties.customErrMsg( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray = errorArray.concat( result.errorArray );
        }
    }

    /** 入力項目ID */
    result = LIBRARY.validation.properties.inputId( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 一覧項目表示名 */
    result = LIBRARY.validation.properties.itemViewNames( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray = errorArray.concat( result.errorArray );
        }
    }

    /** ラベル幅 */
    result = LIBRARY.validation.properties.labelSize( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 入力項目横幅 */
    result = LIBRARY.validation.properties.inputFieldSize( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 入力項目高さ */
    result = LIBRARY.validation.properties.inputFieldHeight( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** アイテム名 */
    result = LIBRARY.validation.properties.itemName( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray = errorArray.concat( result.errorArray );
        }
    }

    /** 表示タイプ */
    result = LIBRARY.validation.properties.itemViewType( setting, serverFlg );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 幅 */
    result = LIBRARY.validation.properties.styles( setting, serverFlg, 'width' );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 高さ */
    result = LIBRARY.validation.properties.styles( setting, serverFlg, 'height' );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 左位置 */
    result = LIBRARY.validation.properties.styles( setting, serverFlg, 'left' );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** 上位置 */
    result = LIBRARY.validation.properties.styles( setting, serverFlg, 'top' );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** ラベルのフォントサイズ */
    result = LIBRARY.validation.properties.labelFontSize( setting, serverFlg, 0 );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** ラベルの文字色 */
    result = LIBRARY.validation.properties.labelFontColor( setting, serverFlg, 0 );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** ラベル背景色 */
    result = LIBRARY.validation.properties.labelBackgroundColor( setting, serverFlg, 0 );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** フィールドのフォントサイズ */
    result = LIBRARY.validation.properties.inputFontSize( setting, serverFlg, 0 );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** フィールドの文字色 */
    result = LIBRARY.validation.properties.inputFontColor( setting, serverFlg, 0 );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    /** フィールド背景色 */
    result = LIBRARY.validation.properties.inputBackgroundColor( setting, serverFlg, 0 );

    if( result.error ){

        if( serverFlg ){
            return result;
        }else{
            errorArray.push( result );
        }
    }

    return errorArray;
}

/**
 * アイテム使用外部ファイル設定
 *
 * ユーザ入力時にロードする必要のある外部ファイルを記述する
 * 返却形式 : { type : {String} ファイルタイプ(javascript|jsspRpc|stylesheet)
 *              src : {String} ファイルパス(javascriptの場合のみ)
 *              href : {String} ファイルパス(stylesheetの場合のみ)
 *              media : {String} スタイル適用メディアタイプ(stylesheetの場合のみ)
 *            }
 * ロードファイルが複数ある場合は、上記形式を配列にして返却。
 * ロードする必要がない場合は空objectを返却する。
 *
 * @return {Object} ロードファイル設定情報
 */
function getHeaderSettingList() {

    return [
      {
      'type':'javascript',
      'src' :'forma/csjs/im_forma_cooperation.js'
      },
      {
        'type'      : 'javascript',
        'src'       : 'forma/csjs/types/sample/item/sp/sp_imwComment.js',
        'clientType': 'sp'
      }
   ];
}